@@ -1,10 +1,15 @@
 '''
 @license: GNU Lesser General Public License v3.0 (see LICENSE)
 '''
+from __future__ import absolute_import
+from __future__ import unicode_literals
 
-
-from ofx_file import (BankAccount, File, Response, Balance,
-                      TransactionList, Transaction)
+from .ofx_file import (BankAccount,
+                       File,
+                       Response,
+                       Balance,
+                       TransactionList,
+                       Transaction)
 
 #: conversion table OFX - Homebank for pay modes
 PAYMODES = {'01': 10,
