@@ -1,8 +1,11 @@
 
+from __future__ import unicode_literals
+from __future__ import absolute_import
+
 import unittest
 
-from csb43.csb43 import item
-from csb43.utils import utils
+from ..csb43 import item
+from .. import utils
 
 
 class TestCsbItem(unittest.TestCase):
@@ -23,24 +26,24 @@ class TestCsbItem(unittest.TestCase):
 
     def test_init_bad_code(self):
 
-        record = '22' + '0'*78
+        record = '22' + '0' * 78
 
         with self.assertRaises(utils.Csb43Exception):
             item.Item(record)
 
     def test_init_bad_record_code(self):
 
-        record = '2306' + '0'*76
+        record = '2306' + '0' * 76
 
         with self.assertRaises(utils.Csb43Exception):
             item.Item(record)
 
-        record = '2315' + '0'*76
+        record = '2315' + '0' * 76
 
         with self.assertRaises(utils.Csb43Exception):
             item.Item(record)
 
-        record = '2305' + '0'*76
+        record = '2305' + '0' * 76
 
         item.Item(record)
 
@@ -73,7 +76,7 @@ class TestCsbItem(unittest.TestCase):
 
         self.assertEqual(value.rstrip(' '), self.item.item1)
 
-        value = '0123456789ABCDEF G '*2
+        value = '0123456789ABCDEF G ' * 2
         self.item.item1 = value
 
         self.assertEqual(value.rstrip(' '), self.item.item1)
@@ -88,7 +91,7 @@ class TestCsbItem(unittest.TestCase):
 
         self.assertEqual(value.rstrip(' '), self.item.item2)
 
-        value = '0123456789ABCDEF G '*2
+        value = '0123456789ABCDEF G ' * 2
         self.item.item2 = value
 
         self.assertEqual(value.rstrip(' '), self.item.item2)
@@ -126,4 +129,3 @@ class TestCsbItem(unittest.TestCase):
         self.assertEqual(1, len(r))
 
         self.assertEqual(str(self.item), r[0])
-
