@@ -1,9 +1,13 @@
 
+from __future__ import unicode_literals
+from __future__ import absolute_import
+
 import unittest
 import datetime
 
-from csb43.csb43 import Transaction, Item, Exchange
-from csb43.utils import utils
+from ..csb43 import Transaction, Item, Exchange
+from .. import utils
+
 
 class TestCsbTransaction(unittest.TestCase):
 
@@ -17,15 +21,15 @@ class TestCsbTransaction(unittest.TestCase):
             Transaction(record)
 
     def test_init_bad_code(self):
-        record = '25' + ('1'*78)
+        record = '25' + ('1' * 78)
 
         with self.assertRaises(utils.Csb43Exception):
             Transaction(record)
 
     def test_init(self):
-        record = '22' + ('0'*25)
+        record = '22' + ('0' * 25)
         record += '1'
-        record += ('0'*52)
+        record += ('0' * 52)
 
         Transaction(record)
 
@@ -35,7 +39,7 @@ class TestCsbTransaction(unittest.TestCase):
 
         self.assertIsNone(self.t.amount)
 
-        value = '12345'*4
+        value = '12345' * 4
 
         with self.assertRaises(utils.Csb43Exception):
             self.t.amount = value
@@ -105,7 +109,7 @@ class TestCsbTransaction(unittest.TestCase):
     def test_exchange(self):
         self.assertIsNone(self.t.exchange)
 
-        value = '2401978' + '0'*(14+59)
+        value = '2401978' + '0' * (14 + 59)
         self.t.add_exchange(value)
 
         self.assertIsInstance(self.t.exchange, Exchange)
@@ -120,12 +124,12 @@ class TestCsbTransaction(unittest.TestCase):
 
         self.assertListEqual([value], self.t.optionalItems)
 
-        value = '2305' + '0'*76
+        value = '2305' + '0' * 76
         self.t.add_item(value)
 
         self.assertEqual(2, len(self.t.optionalItems))
 
-        for n in xrange(3):
+        for n in range(3):
             self.t.add_item(Item())
 
         self.assertEqual(5, len(self.t.optionalItems))
@@ -137,7 +141,6 @@ class TestCsbTransaction(unittest.TestCase):
 
         self.assertIsNone(self.t.ownItem)
 
-
         self.assertIsNone(self.t.sharedItem)
 
         value = 'asd'
@@ -288,7 +291,8 @@ class TestCsbTransaction(unittest.TestCase):
         self.assertIsInstance(self.t.exchange, Exchange)
 
         self.assertEqual(e.amount, self.t.exchange.amount)
-        self.assertEqual(e.sourceCurrency.letter, self.t.exchange.sourceCurrency.letter)
+        self.assertEqual(e.sourceCurrency.letter,
+                         self.t.exchange.sourceCurrency.letter)
 
     def test_add_exchange2(self):
 
@@ -301,7 +305,8 @@ class TestCsbTransaction(unittest.TestCase):
         self.assertIsInstance(self.t.exchange, Exchange)
 
         self.assertEqual(e.amount, self.t.exchange.amount)
-        self.assertEqual(e.sourceCurrency.letter, self.t.exchange.sourceCurrency.letter)
+        self.assertEqual(e.sourceCurrency.letter,
+                         self.t.exchange.sourceCurrency.letter)
 
     def test_iter(self):
 
